from django.contrib import admin

# Register your models here.

from Zephyrus.instagram.models import InstagramPhoto


class InstagramPhotoAdmin(admin.ModelAdmin):
    list_display = (
        'userUrl', 'limit',
    )

admin.site.register(InstagramPhoto, InstagramPhotoAdmin)
